glutton_runtime

Module xcm_config

Structs

JustTheParent
KusamaLocation
KusamaNetwork
MaxAssetsIntoHolding
MaxInstructions
UnitWeightCost
UniversalLocation
XcmConfig

Type Aliases

XcmOriginToTransactDispatchOrigin
This is the type we use to convert an (incoming) XCM origin into a local Origin instance, ready for dispatching a transaction with Xcm’s Transact. There is an OriginKind which can bias the kind of local Origin it will become.